@@ -99,16 +99,14 @@ class Generation(RevPySam, ABC):
             res_mean['ws_mean'] = resource['mean_windspeed', idx]
 
         else:
-            if 'dni_mean' in out_req_nomeans:
-                out_req_nomeans.remove('dni_mean')
-                res_mean = {}
-                res_mean['dni_mean'] = resource['mean_dni', idx] / 1000 * 24
-
-            if 'ghi_mean' in out_req_nomeans:
-                out_req_nomeans.remove('ghi_mean')
-                if res_mean is None:
-                    res_mean = {}
-                res_mean['ghi_mean'] = resource['mean_ghi', idx] / 1000 * 24
+            for var in ('dni', 'dhi', 'ghi'):
+                label_1 = '{}_mean'.format(var)
+                label_2 = 'mean_{}'.format(var)
+                if label_1 in out_req_nomeans:
+                    out_req_nomeans.remove(label_1)
+                    if res_mean is None:
+                        res_mean = {}
+                    res_mean[label_1] = resource[label_2, idx] / 1000 * 24
 
         return res_mean, out_req_nomeans
 
@@ -559,6 +557,18 @@ class Pvwatts(Solar, ABC):
 
     def gen_profile(self):
         """Get AC inverter power generation profile (orig timezone) in kW.
+        This is an alias of the "ac" SAM output variable.
+
+        Returns
+        -------
+        output : np.ndarray
+            1D array of hourly AC inverter power generation in kW.
+            Datatype is float32 and array length is 8760*time_interval.
+        """
+        return self.ac()
+
+    def ac(self):
+        """Get AC inverter power generation profile (orig timezone) in kW.
 
         Returns
         -------
@@ -568,6 +578,17 @@ class Pvwatts(Solar, ABC):
         """
         return np.array(self['ac'], dtype=np.float32) / 1000
 
+    def dc(self):
+        """Get DC array power generation profile (orig timezone) in kW.
+
+        Returns
+        -------
+        output : np.ndarray
+            1D array of hourly DC array power generation in kW.
+            Datatype is float32 and array length is 8760*time_interval.
+        """
+        return np.array(self['dc'], dtype=np.float32) / 1000
+
     @property
     def default(self):
         """Get the executed default pysam PVWATTS object."""
@@ -588,6 +609,8 @@ class Pvwatts(Solar, ABC):
                              'annual_energy': self.annual_energy,
                              'energy_yield': self.energy_yield,
                              'gen_profile': self.gen_profile,
+                             'ac': self.ac,
+                             'dc': self.dc,
                              }
 
         super().collect_outputs(output_lookup=output_lookup)
