@@ -58,9 +58,15 @@ class Gen:
                  'dhi': {'scale_factor': 1, 'units': 'W/m2',
                          'dtype': 'uint16', 'chunks': (None, 100),
                          'type': 'array'},
+                 'ghi': {'scale_factor': 1, 'units': 'W/m2',
+                         'dtype': 'uint16', 'chunks': (None, 100),
+                         'type': 'array'},
                  'dni_mean': {'scale_factor': 1000, 'units': 'kWh/m2/day',
                               'dtype': 'uint16', 'chunks': None,
                               'type': 'scalar'},
+                 'dhi_mean': {'scale_factor': 1000, 'units': 'kWh/m2/day',
+                              'dtype': 'uint16', 'chunks': None,
+                              'type': 'scalar'},
                  'ghi_mean': {'scale_factor': 1000, 'units': 'kWh/m2/day',
                               'dtype': 'uint16', 'chunks': None,
                               'type': 'scalar'},
@@ -94,6 +100,12 @@ class Gen:
                  'gen_profile': {'scale_factor': 1, 'units': 'kW',
                                  'dtype': 'float32', 'chunks': (None, 100),
                                  'type': 'array'},
+                 'ac': {'scale_factor': 1, 'units': 'kW',
+                        'dtype': 'float32', 'chunks': (None, 100),
+                        'type': 'array'},
+                 'dc': {'scale_factor': 1, 'units': 'kW',
+                        'dtype': 'float32', 'chunks': (None, 100),
+                        'type': 'array'},
                  'poa': {'scale_factor': 1, 'units': 'W/m2',
                          'dtype': 'float32', 'chunks': (None, 100),
                          'type': 'array'},
